@@ -1,4 +1,4 @@
-/*  $Id: FrenchVerbDictionary.h,v 1.44 2012/04/24 02:46:05 sarrazip Exp $
+/*  $Id: FrenchVerbDictionary.h,v 1.48 2017/10/09 19:56:01 sarrazip Exp $
     FrenchVerbDictionary.h - Dictionary of verbs and conjugation templates
 
     verbiste - French conjugation system
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 
 #ifndef _H_FrenchVerbDictionary
@@ -68,6 +68,8 @@ public:
 
     /** Returns the full path names of the conjugation and verb XML files
         for the given language code.
+        If the environment variable LIBDATADIR is defined, its value is
+        used as the directory where to find those XML files.
         @param  conjFN          receives the full path of the conjugation template XML file
         @param  verbsFN         receives the full path of the verb list XML file
         @param  languageCode    "fr" for French or "it" for Italian
@@ -90,8 +92,7 @@ public:
     FrenchVerbDictionary(const std::string &conjugationFilename,
                         const std::string &verbsFilename,
                         bool includeWithoutAccents,
-                        Language lang)
-                                        throw (std::logic_error);
+                        Language lang);
 
     /** Load the French conjugation database.
         Uses the default (hard-coded) location for the French dictionary's
@@ -103,7 +104,7 @@ public:
                                         (if verbs or template names are
                                         mentioned, they are in Latin-1)
     */
-    FrenchVerbDictionary(bool includeWithoutAccents) throw (std::logic_error);
+    FrenchVerbDictionary(bool includeWithoutAccents);
 
     /** Frees the memory used by this dictionary.
     */
@@ -196,7 +197,7 @@ public:
                                 if the given conjugated verb is unknown
     */
     void deconjugate(const std::string &utf8ConjugatedVerb,
-                            std::vector<InflectionDesc> &results);
+                     std::vector<InflectionDesc> &results);
 
     /** Returns the English name (in ASCII) of the given mode.
     */
@@ -223,13 +224,13 @@ public:
         @param      utf8String  UTF-8 string to be converted
         @returns                Unicode string
     */
-    std::wstring utf8ToWide(const std::string &utf8String) const throw(int);
+    std::wstring utf8ToWide(const std::string &utf8String) const;
 
     /** Converts a wide character string to a UTF-8 string.
         @param      wideString  Unicode string to be converted
         @returns                UTF-8 string
     */
-    std::string wideToUTF8(const std::wstring &wideString) const throw(int);
+    std::string wideToUTF8(const std::wstring &wideString) const;
 
     /** Removes accents from accented letters in the given string.
         @param   utf8String     UTF-8 string with accented characters
@@ -251,8 +252,8 @@ public:
                                 clear the vector beforehand)
     */
     void formUTF8UnaccentedVariants(const std::wstring &wideString,
-                                        size_t index,
-                                        std::vector<std::string> &utf8Variants);
+                                    size_t index,
+                                    std::vector<std::string> &utf8Variants);
 
     /** Returns all unaccented variants of a UTF-8 string.
         If N letters are accented in 'utf8String', then 2^N variants
@@ -268,8 +269,8 @@ public:
                                 clear the vector beforehand)
     */
     void formUTF8UnaccentedVariants(const std::string &utf8String,
-                                        size_t index,
-                                        std::vector<std::string> &utf8Variants);
+                                    size_t index,
+                                    std::vector<std::string> &utf8Variants);
 
 
     /** Returns the content of an XML node in UTF-8.
@@ -282,8 +283,7 @@ public:
         @throws    int          errno value set by iconv(3), in the case of a
                                 UTF-8 to Latin-1 conversion error
     */
-    std::string getUTF8XmlNodeText(
-                        xmlDocPtr doc, xmlNodePtr node) throw(int);
+    std::string getUTF8XmlNodeText(xmlDocPtr doc, xmlNodePtr node);
 
     /** Returns the content of an XML property in UTF-8.
         For example, if 'node' represents <foo type='xyz'/>,
@@ -296,8 +296,7 @@ public:
         @throws   int           errno value set by iconv(3), in the case of a
                                 UTF-8 to Latin-1 conversion error
     */
-    std::string getUTF8XmlProp(
-                        xmlNodePtr node, const char *propName) throw(int);
+    std::string getUTF8XmlProp(xmlNodePtr node, const char *propName);
 
 
     /** Gets the radical part of an infinitive, according to a template name.
@@ -306,9 +305,8 @@ public:
         @returns                a prefix of 'infinitive'
         @throws   logic_error   the template name is invalid (no ':' found)
     */
-    static std::string getRadical(
-                    const std::string &infinitive,
-                    const std::string &templateName) throw(std::logic_error);
+    static std::string getRadical(const std::string &infinitive,
+                                  const std::string &templateName);
 
     /** Generates the conjugation of a verb for a given mode and tense.
         The generated words are complete, they are not just inflections.
@@ -331,13 +329,13 @@ public:
                                 tense is unknown.
     */
     bool generateTense(const std::string &radical,
-                        const TemplateSpec &templ,
-                        Mode mode,
-                        Tense tense,
-                        std::vector< std::vector<std::string> > &dest,
-                        bool includePronouns,
-                        bool aspirateH,
-                        bool isItalian) const throw();
+                       const TemplateSpec &templ,
+                       Mode mode,
+                       Tense tense,
+                       std::vector< std::vector<std::string> > &dest,
+                       bool includePronouns,
+                       bool aspirateH,
+                       bool isItalian) const;
 
     /** Indicates if the given verb starts with an aspirate h.
         An aspirate h means that one cannot make a contraction or liaison
@@ -346,8 +344,7 @@ public:
         The verb "habiter" however does not have an aspirate h, so one
         says "j'habite" and not "je habite".
     */
-    bool isVerbStartingWithAspirateH(
-                                const std::string &infinitive) const throw();
+    bool isVerbStartingWithAspirateH(const std::string &infinitive) const;
 
     /** Returns the code representing this dictionary's language.
     */
@@ -406,8 +403,7 @@ private:
         virtual void onFoundPrefixWithUserData(
                         const std::wstring &conjugatedVerb,
                         std::wstring::size_type index,
-                        const std::vector<TrieValue> *templateList) const
-                                                                throw();
+                        const std::vector<TrieValue> *templateList) const;
 
         /** Sets the destination vector in which callback() stores results.
             When the Trie<>::get() method is called on this object,
@@ -447,21 +443,14 @@ private:
 
     void init(const std::string &conjugationFilename,
                         const std::string &verbsFilename,
-                        bool includeWithoutAccents)
-                                        throw (std::logic_error);
+                        bool includeWithoutAccents);
     void loadConjugationDatabase(const char *conjugationFilename,
-                                bool includeWithoutAccents)
-                                        throw (std::logic_error);
-    void loadVerbDatabase(const char *verbsFilename,
-                        bool includeWithoutAccents)
-                                        throw (std::logic_error);
-    void readConjugation(xmlDocPtr doc,
-                        bool includeWithoutAccents) throw(std::logic_error);
+                                 bool includeWithoutAccents);
+    void loadVerbDatabase(const char *verbsFilename, bool includeWithoutAccents);
+    void readConjugation(xmlDocPtr doc, bool includeWithoutAccents);
     static void generateOtherPastParticiple(const char *mascSing,
-                                        std::vector<std::string> &dest);
-    void readVerbs(xmlDocPtr doc,
-                   bool includeWithoutAccents)
-                                throw(std::logic_error);
+                                            std::vector<std::string> &dest);
+    void readVerbs(xmlDocPtr doc, bool includeWithoutAccents);
     void insertVerbRadicalInTrie(const std::string &verbRadical,
                                     const std::string &tname,
                                     const std::string &correctVerbRadical);
